/* ------------------------------------------------------------------------- */
/*
 *  smb.js
 *
 *  Copyright (c) 2011, clown.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *    - Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *    - Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 *    - No names of its contributors may be used to endorse or promote
 *      products derived from this software without specific prior written
 *      permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 *  TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 *  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 *  LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 *  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 *  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
/* ------------------------------------------------------------------------- */
document.write('<script src="md5.js" type="text/javascript"></script>');

var smb = new function() {
    /* --------------------------------------------------------------------- */
    //  variables
    /* --------------------------------------------------------------------- */
    var horizontal  = 7; // ソーシャルボタン間の水平方向のマージン
    var vertical    = 2; // 小さなボタンを上下中央に揃えるためのマージン
    
    /* --------------------------------------------------------------------- */
    //  escape
    /* --------------------------------------------------------------------- */
    var escape = function(str) {
        return str.replace(/<|>|&|'|"|\s/g, function(s){
            var map = {"<":"&lt;", ">":"&gt;", "&":"&amp;", "'":"&#39;", "\"":"&quot;", " ":"&nbsp;"};
            return map[s];
        });
    };
    
    /* --------------------------------------------------------------------- */
    /*
     *  md5
     *
     *  CybozuLabs.MD5 を利用して MD5 ハッシュ値を計算する．
     *  http://labs.cybozu.co.jp/blog/mitsunari/2007/07/md5js_1.html
     */
    /* --------------------------------------------------------------------- */
    var md5 = function(str) {
        return CybozuLabs.MD5.calc(str);
    };
    
    /* --------------------------------------------------------------------- */
    /*
     *  show_twitter
     *
     *  Twitter のソーシャルボタンを表示する．
     *  http://twitter.com/goodies/tweetbutton
     */
    /* --------------------------------------------------------------------- */
    var show_twitter = function(show_count) {
        var count = show_count ? "horizontal" : "none";
        document.write('<a href="http://twitter.com/share"');
        document.write(' class="twitter-share-button"');
        document.write(' data-count="' + count + '"');
        document.write(' data-lang="ja"');
        document.write('>Tweet</a>');
        document.write('<script type="text/javascript" src="http://platform.twitter.com/widgets.js"></script>');
        
        if (!show_count) document.write('<span style="margin-left:' + horizontal + 'px;"></span>');
    };
    
    /* --------------------------------------------------------------------- */
    /*
     *  show_facebook
     *
     *  Facebook のソーシャルボタン（「いいね！」ボタン）を表示する．
     *  NOTE: Facebook はカウントの非表示が効かない．
     *  http://developers.facebook.com/docs/reference/plugins/like/
     */
    /* --------------------------------------------------------------------- */
    var show_facebook = function(show_count) {
        document.write('<iframe src="http://www.facebook.com/plugins/like.php?href=' + encodeURIComponent(location.href));
        document.write('&amp;layout=button_count');
        document.write('&amp;show_faces=true');
        document.write('&amp;width=100');
        document.write('&amp;action=like');
        document.write('&amp;colorscheme=light');
        document.write('&amp;height=21"');
        document.write(' scrolling="no" frameborder="0" allowTransparency="true"');
        document.write(' style="border:none; overflow:hidden; width:100px; height:21px; position:relative; top:1px;"');
        document.write('></iframe>');
        document.write('<span style="margin-left:' + horizontal + 'px;"></span>');
    };
    
    /* --------------------------------------------------------------------- */
    /*
     *  show_gree
     *
     *  GREE の Social Feedback ボタンを表示する．
     *  NOTE: Facebook はカウントの表示機能が存在しない？
     *  http://developer.gree.co.jp/connect/plugins/sf
     */
    /* --------------------------------------------------------------------- */
    var show_gree = function(show_count) {
        document.write('<iframe src="http://share.gree.jp/share?url=' + encodeURIComponent(location.href));
        document.write('&amp;type=0');
        document.write('&amp;height=20"');
        document.write(' scrolling="no" frameborder="0" marginwidth="0" marginheight="0" allowTransparency="true"');
        document.write(' style="border:none; overflow:hidden; width:70px; height:20px;"');
        document.write('></iframe>');
        document.write('<span style="margin-left:' + horizontal + 'px;"></span>');
    }
    
    /* --------------------------------------------------------------------- */
    /*
     *  show_hatena
     *
     *  はてなブックマークボタンを表示する．
     *  http://b.hatena.ne.jp/guide/bbutton
     */
    /* --------------------------------------------------------------------- */
    var show_hatena = function(show_count) {
        var count = show_count ? "standard" : "simple";
        
        document.write('<a href="http://b.hatena.ne.jp/entry/' + escape(location.href) + '"');
        document.write(' class="hatena-bookmark-button"');
        document.write(' data-hatena-bookmark-layout="' + count + '"');
        document.write('>');
        
        document.write('<img src="http://b.st-hatena.com/images/entry-button/button-only.gif"');
        document.write(' alt="このエントリーを含むはてなブックマーク" width="20" height="20"');
        document.write(' style="border:none;"');
        document.write(' />');
        
        document.write('</a>');
        
        document.write('<script type="text/javascript" src="http://b.st-hatena.com/js/bookmark_button.js"');
        document.write(' charset="utf-8" async="async"');
        document.write('></script>');
        document.write('<span style="margin-left:' + horizontal + 'px;"></span>');
    };
    
    /* --------------------------------------------------------------------- */
    /*
     *  show_hatena_old
     *
     *  旧タイプのはてなブックマークボタンを表示する．
     */
    /* --------------------------------------------------------------------- */
    var show_hatena_old = function(show_count) {
        var uri = escape(location.href);
        
        document.write('<a href="http://b.hatena.ne.jp/entry/' + uri + '"');
        document.write(' target="_blank"');
        document.write('>');
        
        document.write('<img src="http://b.hatena.ne.jp/images/entry.gif"');
        document.write(' alt="このエントリーを含むはてブックマーク" width="16" height="12"');
        document.write(' style="border:none; margin-bottom:' + vertical + 'px;"');
        document.write(' />');
        document.write('</a>');
        
        if (show_count) {
            document.write('<span style="margin-left:2px;"></span>');
            
            document.write('<a href="http://b.hatena.ne.jp/entry/' + uri + '"');
            document.write(' target="_blank"');
            document.write('>');
            
            document.write('<img src="http://b.hatena.ne.jp/entry/image/' + uri + '"');
            document.write(' alt="このエントリーのはてブックマーク数"');
            document.write(' style="border:none; margin-bottom:' + vertical + 'px"');
            document.write(' />');
            
            document.write('</a>');
        }
        
        document.write('<span style="margin-left:' + horizontal + 'px;"></span>');
    };
    
    /* --------------------------------------------------------------------- */
    /*
     *  show_evernote
     *
     *  Evernote のソーシャルボタンを表示する．
     *  NOTE: Evernote はカウントの表示機能が存在しない．
     *  http://www.evernote.com/about/developer/sitememory/
     */
    /* --------------------------------------------------------------------- */
    var show_evernote = function(show_count) {
        document.write('<script type="text/javascript" src="http://static.evernote.com/noteit.js"></script>');
        document.write('<a href="#" onclick="Evernote.doClip({}); return false;">');
        
        if (show_count) document.write('<img src="http://static.evernote.com/article-clipper-jp.png"');
        else document.write('<img src="http://static.evernote.com/site-mem-16.png"');
        document.write(' alt="このエントリーを Evernote に追加"');
        document.write(' style="border:none; margin-bottom:' + vertical + 'px;"');
        document.write(' />');
        
        document.write('</a>');
        document.write('<span style="margin-left:' + horizontal + 'px;"></span>');
    };
    
    /* --------------------------------------------------------------------- */
    /*
     *  show_delicious
     *
     *  Delicious のブックマークボタンを表示する．
     *  NOTE: Delicious はカウントの表示機能が存在しない．
     */
    /* --------------------------------------------------------------------- */
    var show_delicious = function(show_count) {
        document.write('<a href="http://www.delicious.com/url/' + md5(location.href) + '"');
        document.write(' target="_blank"');
        document.write('>');
        
        document.write('<img src="http://l.yimg.com/hr/img/delicious16.gif"');
        document.write(' alt="このエントリーを含む delicious ブックマーク" width="16" height="16"');
        document.write(' style="border:none; margin-bottom:' + vertical + 'px;"');
        document.write(' />');
        
        document.write('</a>');
        document.write('<span style="margin-left:' + horizontal + 'px;"></span>');
    };
    
    /* --------------------------------------------------------------------- */
    /*
     *  show_livedoor
     *
     *  livedoor クリップのクリップボタンを表示する．
     */
    /* --------------------------------------------------------------------- */
    var show_livedoor = function(show_count) {
        var uri = escape(location.href);
        document.write('<a href="http://clip.livedoor.com/page/' + uri + '"');
        document.write(' target="_blank"');
        document.write('>');
        
        document.write('<img src="http://parts.blog.livedoor.jp/img/cmn/clip_16_16_w.gif"');
        document.write(' alt="このエントリーを含む livedoor クリップ" width="16" height="16"');
        document.write(' style="border:none; margin-bottom:' + vertical + 'px;"');
        document.write(' />');
        
        document.write('</a>');
        
        if (show_count) {
            document.write('<span style="margin-left:2px;"></span>');
            
            document.write('<a href="http://clip.livedoor.com/page/' + uri + '"');
            document.write(' target="_blank"');
            document.write('>');
            
            document.write('<img src="http://image.clip.livedoor.com/counter/medium/' + uri + '"');
            document.write(' alt="このエントリーの livedoor クリップ数"');
            document.write(' style="border:none; margin-bottom:' + vertical + 'px;"');
            document.write(' />');
            
            document.write('</a>');
        }
        
        document.write('<span style="margin-left:' + horizontal + 'px;"></span>');
    };
    
    /* --------------------------------------------------------------------- */
    /*
     *  show_buzzurl
     *
     *  Buzzurl のブックマークボタンを表示する．
     */
    /* --------------------------------------------------------------------- */
    var show_buzzurl = function(show_count) {
        var uri = escape(location.href);
        document.write('<a href="http://buzzurl.jp/entry/' + uri + '"');
        document.write(' target="_blank"');
        document.write('>');
        
        document.write('<img src="http://buzzurl.jp/static/image/api/icon/add_icon_mini_08.gif"');
        document.write(' alt="このエントリーを含む Buzzurl ブックマーク" width="16" height="16"');
        document.write(' style="border:none; margin-bottom:' + vertical + 'px;"');
        document.write(' />');
        
        document.write('</a>');
        
        if (show_count) {
            document.write('<span style="margin-left:2px;"></span>');
            
            document.write('<a href="http://buzzurl.jp/entry/' + uri + '"');
            document.write(' target="_blank"');
            document.write('>');
            
            document.write('<img src="http://api.buzzurl.jp/api/counter/' + uri + '"');
            document.write(' alt="このエントリーの Buzzurl 登録数"');
            document.write(' style="border:none; margin-bottom:' + vertical + 'px;"');
            document.write(' />');
            
            document.write('</a>');
        }
        
        document.write('<span style="margin-left:' + horizontal + 'px;"></span>');
    };
    
    /* --------------------------------------------------------------------- */
    /*
     *  show_yahoo
     *
     *  Yahoo! ブックマークのブックマークボタンを表示する．
     */
    /* --------------------------------------------------------------------- */
    var show_yahoo = function(show_count) {
        var uri = escape(location.href);
        document.write('<a href="http://bookmarks.yahoo.co.jp/url?url=' + uri);
        document.write('&amp;opener=bm&amp;ei=UTF-8"');
        document.write(' target="_blank"');
        document.write('>');
        
        document.write('<img src="http://i.yimg.jp/images/sicons/ybm16.gif"');
        document.write(' alt="このエントリーを含む Yahoo! ブックマーク" width="16" height="16"');
        document.write(' style="border:none; margin-bottom:' + vertical + 'px;"');
        document.write(' />');
        
        document.write('</a>');
        
        if (show_count) {
            document.write('<span style="margin-left:2px;"></span>');
            
            document.write('<a href="http://bookmarks.yahoo.co.jp/url?url=' + uri);
            document.write('&amp;opener=bm&amp;ei=UTF-8"');
            document.write(' target="_blank"');
            document.write('>');
            
            document.write('<img src="http://num.bookmarks.yahoo.co.jp/image/small/' + uri + '"');
            document.write(' alt="このエントリーの Yahoo! ブックマーク登録数"');
            document.write(' style="border:none; margin-bottom:' + vertical + 'px;"')
            document.write(' />');
            
            document.write('</a>');
        }
        
        document.write('<span style="margin-left:' + horizontal + 'px;"></span>');
    };
    
    /* --------------------------------------------------------------------- */
    /*
     *  show_newsing
     *
     *  Delicious のピックアップボタンを表示する．
     *  NOTE: newsing はカウントの表示機能が存在しない．
     */
    /* --------------------------------------------------------------------- */
    var show_newsing = function(show_count) {
        document.write('<a href="http://newsing.jp/nbutton?title=' + encodeURIComponent(document.title));
        document.write('&amp;url=' + encodeURIComponent(location.href) + '"');
        document.write(' target="_blank"');
        document.write('>');
        
        // or http://image.newsing.jp/common/images/newsingit/newsingit_s.gif
        document.write('<img src="http://image.newsing.jp/common/images/newsingit/newsing_button_16.gif"');
        document.write(' alt="このエントリーを newsing でピックアップ" width="16" height="16"');
        document.write(' style="border:none; margin-bottom:' + vertical + 'px"');
        document.write(' />');
        
        document.write('</a>');
        document.write('<span style="margin-left:' + horizontal + 'px;"></span>');
    }
    
    /* --------------------------------------------------------------------- */
    //  public variables/functions
    /* --------------------------------------------------------------------- */
    var public = {
        /* ----------------------------------------------------------------- */
        //  constant
        /* ----------------------------------------------------------------- */
        twitter    : 0x0001,
        facebook   : 0x0002,
        hatena     : 0x0004,
        hatena_old : 0x0008,
        delicious  : 0x0010,
        livedoor   : 0x0020,
        yahoo      : 0x0040,
        buzzurl    : 0x0080,
        evernote   : 0x0100,
        newsing    : 0x0200,
        gree       : 0x0400,
        
        /* ----------------------------------------------------------------- */
        /*
         *  show
         *
         *  メイン関数．
         *
         *  引数 kind には twitter, facebook, hatena, hatena_old,
         *  delicious, livedoor, yahoo, buzzurl, evernote のうち，
         *  表示したいものを | 演算子で繋げて指定する．
         */
        /* ----------------------------------------------------------------- */
        show : function(kind, show_count) {
            if ((kind & this.hatena_old) != 0)  show_hatena_old(show_count);
            if ((kind & this.delicious) != 0)   show_delicious(show_count);
            if ((kind & this.livedoor) != 0)    show_livedoor(show_count);
            if ((kind & this.yahoo) != 0)       show_yahoo(show_count);
            if ((kind & this.buzzurl) != 0)     show_buzzurl(show_count);
            if ((kind & this.newsing) != 0)     show_newsing(show_count);
            if ((kind & this.evernote) != 0)    show_evernote(show_count);
            if ((kind & this.hatena) != 0)      show_hatena(show_count);
            if ((kind & this.twitter) != 0)     show_twitter(show_count);
            if ((kind & this.gree) != 0)        show_gree(show_count);
            if ((kind & this.facebook) != 0)    show_facebook(show_count);
        }
    };
    
    return public;
}
